

/*********************************************************************
 *
 *	Hardware specific definitions
 *
 *********************************************************************
 * FileName:        HardwareProfile.h
 * Dependencies:    None
 * Processor:       PIC18, PIC24F, PIC24H, dsPIC30F, dsPIC33F, PIC32
 * Compiler:        Microchip C32 v1.10 or higher
 *					Microchip C30 v3.12 or higher
 *					Microchip C18 v3.34 or higher
 *					HI-TECH PICC-18 PRO 9.63PL2 or higher
 * Company:         Microchip Technology, Inc.
 *
 * Software License Agreement
 *
 * Copyright (C) 2002-2009 Microchip Technology Inc.  All rights
 * reserved.
 *
 * Microchip licenses to you the right to use, modify, copy, and
 * distribute:
 * (i)  the Software when embedded on a Microchip microcontroller or
 *      digital signal controller product ("Device") which is
 *      integrated into Licensee's product; or
 * (ii) ONLY the Software driver source files ENC28J60.c, ENC28J60.h,
 *		ENCX24J600.c and ENCX24J600.h ported to a non-Microchip device
 *		used in conjunction with a Microchip ethernet controller for
 *		the sole purpose of interfacing with the ethernet controller.
 *
 * You should refer to the license agreement accompanying this
 * Software for additional information regarding your rights and
 * obligations.
 *
 * THE SOFTWARE AND DOCUMENTATION ARE PROVIDED "AS IS" WITHOUT
 * WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT
 * LIMITATION, ANY WARRANTY OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT SHALL
 * MICROCHIP BE LIABLE FOR ANY INCIDENTAL, SPECIAL, INDIRECT OR
 * CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST DATA, COST OF
 * PROCUREMENT OF SUBSTITUTE GOODS, TECHNOLOGY OR SERVICES, ANY CLAIMS
 * BY THIRD PARTIES (INCLUDING BUT NOT LIMITED TO ANY DEFENSE
 * THEREOF), ANY CLAIMS FOR INDEMNITY OR CONTRIBUTION, OR OTHER
 * SIMILAR COSTS, WHETHER ASSERTED ON THE BASIS OF CONTRACT, TORT
 * (INCLUDING NEGLIGENCE), BREACH OF WARRANTY, OR OTHERWISE.
 *
 *
 * Author               Date		Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Howard Schlunder		10/03/06	Original, copied from Compiler.h
 * Ken Hesky            07/01/08    Added ZG2100-specific features
 ********************************************************************/
#ifndef __HARDWARE_PROFILE_H
#define __HARDWARE_PROFILE_H

#include "GenericTypeDefs.h"
#include "Compiler.h"


#define T795	// PIC32MX795F512H

// If no hardware profiles are defined, assume that we are using 
// a Microchip demo board and try to auto-select the correct profile
// based on processor selected in MPLAB


// Set configuration fuses (but only once)
#if defined(THIS_IS_STACK_APPLICATION)
	#if defined(__PIC32MX__)
		#pragma config FPLLODIV = DIV_1, FPLLMUL = MUL_20, FPLLIDIV = DIV_2, FWDTEN = OFF, FPBDIV = DIV_1, POSCMOD = XT, FNOSC = PRIPLL, CP = OFF
	#endif
#endif // Prevent more than one set of config fuse definitions

// Clock frequency value.
// This value is used to calculate Tick Counter value

#if defined(__PIC32MX__)
	// PIC32MX processor
	#define GetSystemClock()		(80000000ul)      // Hz
	#define GetInstructionClock()	(GetSystemClock()/1)
	#define GetPeripheralClock()	(GetInstructionClock()/1)	// Set your divider according to your Peripheral Bus Frequency configuration fuse setting
#endif

// Hardware mappings
#if defined(T795)

	#define LED0_TRIS			(TRISBbits.TRISB15)	// Ref D3
	#define LED0_IO				(LATBbits.LATB15)
	#define LED1_TRIS			(TRISBbits.TRISB12)	// Ref D4
	#define LED1_IO				(LATBbits.LATB12)

	#define LED2_TRIS			(TRISEbits.TRISE0)	// Ref D5
	#define LED2_IO				(LATEbits.LATE0)
	#define LED3_TRIS			(TRISEbits.TRISE1)	// Ref D5
	#define LED3_IO				(LATEbits.LATE1)
	#define LED4_TRIS			(TRISEbits.TRISE2)	// Ref D5
	#define LED4_IO				(LATEbits.LATE2)
	#define LED5_TRIS			(TRISEbits.TRISE3)	// Ref D6
	#define LED5_IO				(LATEbits.LATE3)
	#define LED6_TRIS			(TRISEbits.TRISE4)	// Ref D7
	#define LED6_IO				(LATEbits.LATE4)
	#define LED7_TRIS			(TRISEbits.TRISE5)	// Ref D8
	#define LED7_IO				(LATEbits.LATE5)
	#define LED8_TRIS			(TRISEbits.TRISE6)	// Ref D9
	#define LED8_IO				(LATEbits.LATE6)
	#define LED9_TRIS			(TRISEbits.TRISE7)	// Ref D10	// Note: This is multiplexed with BUTTON1
	#define LED9_IO				(LATEbits.LATE7)

	#define LED_GET()			LATE
	#define LED_PUT(a)			LATE

	#define BUTTON0_TRIS		(TRISDbits.TRISD8)	// Ref S4
	#define	BUTTON0_IO			(PORTDbits.RD8)
	#define BUTTON1_TRIS		(TRISDbits.TRISD0)	// Ref S5	// Note: This is multiplexed with LED7
	#define	BUTTON1_IO			(PORTDbits.RD0)
	#define BUTTON2_TRIS		(TRISDbits.TRISD0)	// Ref S6
	#define	BUTTON2_IO			(PORTDbits.RD0)
	#define BUTTON3_TRIS		(TRISDbits.TRISD0)	// Ref S3
	#define	BUTTON3_IO			(PORTDbits.RD0)

	//#define UARTTX_TRIS			(TRISFbits.TRISF8)
	//#define UARTTX_IO			(PORTFbits.RF8)
	//#define UARTRX_TRIS			(TRISFbits.TRISF2)
	//#define UARTRX_IO			(PORTFbits.RF2)

  	#define ZG_CS_TRIS			(TRISBbits.TRISB11)
   	#define ZG_CS_IO			(LATBbits.LATB11)
   	#define ZG_SDI_TRIS			(TRISDbits.TRISD3)
   	#define ZG_SCK_TRIS			(TRISDbits.TRISD1)
   	#define ZG_SDO_TRIS			(TRISDbits.TRISD2)

    #define ZG_RST_TRIS			(TRISDbits.TRISD9)	
   	#define ZG_RST_IO			(LATDbits.LATD9)  
       
	#define ZG_EINT_TRIS	(TRISDbits.TRISD10)  // INT1
	#define ZG_EINT_IO		(PORTDbits.RD10)     
     
    #define XCEN33_TRIS		    (TRISFbits.TRISF1)  
    #define	XCEN33_IO			(PORTFbits.RF1)
    
    #define ZG_EINT_EDGE		(INTCONbits.INT1EP)
    #define ZG_EINT_IE			(IEC0bits.INT1IE)
    #define ZG_EINT_IF			(IFS0bits.INT1IF)
    #define ZG_EINT_IE_CLEAR    IEC0CLR
    #define ZG_EINT_IF_CLEAR    IFS0CLR
    #define ZG_EINT_IE_SET      IEC0SET
    #define ZG_EINT_IF_SET      IFS0SET
    #define ZG_EINT_BIT         0x00000080
    #define ZG_EINT_IPCSET      IPC1SET
    #define ZG_EINT_IPCCLR      IPC1CLR
    #define ZG_EINT_IPC_MASK    0xFF000000
    #define ZG_EINT_IPC_VALUE   0x0C000000
    
    #define ZG_SSPBUF			(SPI3BUF)
    #define ZG_SPISTAT			(SPI3STAT)
   	#define ZG_SPISTATbits		(SPI3STATbits)
   	#define ZG_SPICON1			(SPI3CON)
    #define ZG_SPICON1bits		(SPI3CONbits)       
   	#define ZG_SPI_BRG		    (SPI3BRG)
    #define ZG_MAX_SPI_FREQ     (10000000ul)	// Hz

	#define ZG_SPI_IE_CLEAR     IEC0CLR
    #define ZG_SPI_IF_CLEAR     IFS0CLR
    #define ZG_SPI_INT_BITS     0x03800000 
#endif

	// Select which UART the STACK_USE_UART and STACK_USE_UART2TCP_BRIDGE 
	// options will use.  You can change these to U1BRG, U1MODE, etc. if you 
	// want to use the UART1 module instead of UART2.
	#define UBRG					U2BRG
	#define UMODE					U2MODE
	#define USTA					U2STA
	#define BusyUART()				BusyUART2()
	#define CloseUART()				CloseUART2()
	#define ConfigIntUART(a)		ConfigIntUART2(a)
	#define DataRdyUART()			DataRdyUART2()
	#define OpenUART(a,b,c)			OpenUART2(a,b,c)
	#define ReadUART()				ReadUART2()
	#define WriteUART(a)			WriteUART2(a)
	#define getsUART(a,b,c)			getsUART2(a,b,c)
	#if defined(__C32__)
		#define putsUART(a)			putsUART2(a)
	#else
		#define putsUART(a)			putsUART2((unsigned int*)a)
	#endif
	#define getcUART()				getcUART2()
	#define putcUART(a)				do{while(BusyUART()); WriteUART(a); while(BusyUART()); }while(0)
	#define putrsUART(a)			putrsUART2(a)
#endif
